@@ -75,7 +75,7 @@ anova.caiclist <- function(object, ..., scale=0, test='F'){
 	## OK - now pass the mod parts of those object into anova.lmlist()
 	mods <- lapply(objects, '[[', 'mod')
 	args <- c(mods, list(scale=scale, test=test))
-	anv  <- do.call(getS3method('anova', 'lmlist'), args)
+	anv  <- do.call('anova', args)
 	# attr(anv, 'heading')[1] <- "Analysis of Variance Table from 'caic' objects\n"
 	return(anv)
 }
@@ -99,4 +99,4 @@ coef.caic <- function(object, ...){
 }
 
 
-# plot.data
+# plot.data
\ No newline at end of file
